All of lore.kernel.org
 help / color / mirror / Atom feed
From: Rob Clark <robdclark@gmail.com>
To: dri-devel@lists.freedesktop.org
Subject: [PATCH 5/9] drm/gem: add drm_gem_create_mmap_offset_size()
Date: Wed,  7 Aug 2013 13:41:23 -0400	[thread overview]
Message-ID: <1375897287-8787-6-git-send-email-robdclark@gmail.com> (raw)
In-Reply-To: <1375897287-8787-1-git-send-email-robdclark@gmail.com>

Variant of drm_gem_create_mmap_offset() which doesn't make the
assumption that virtual size and physical size (obj->size) are the same.
This is needed in omapdrm to deal with tiled buffers.  And lets us get
rid of a duplicated and slightly modified version of
drm_gem_create_mmap_offset() in omapdrm.

Signed-off-by: Rob Clark <robdclark@gmail.com>
---
 drivers/gpu/drm/drm_gem.c | 28 ++++++++++++++++++++++++----
 include/drm/drmP.h        |  1 +
 2 files changed, 25 insertions(+), 4 deletions(-)

diff --git a/include/drm/drmP.h b/include/drm/drmP.h
index 1cc765a..d00eb89 100644
--- a/include/drm/drmP.h
+++ b/include/drm/drmP.h
@@ -1668,6 +1668,7 @@ drm_gem_object_handle_unreference_unlocked(struct drm_gem_object *obj)
 
 void drm_gem_free_mmap_offset(struct drm_gem_object *obj);
 int drm_gem_create_mmap_offset(struct drm_gem_object *obj);
+int drm_gem_create_mmap_offset_size(struct drm_gem_object *obj, size_t size);
 
 struct drm_gem_object *drm_gem_object_lookup(struct drm_device *dev,
 					     struct drm_file *filp,
diff --git a/drivers/gpu/drm/drm_gem.c b/drivers/gpu/drm/drm_gem.c
index 1f76572..84d59f7 100644
--- a/drivers/gpu/drm/drm_gem.c
+++ b/drivers/gpu/drm/drm_gem.c
@@ -303,24 +303,44 @@ drm_gem_free_mmap_offset(struct drm_gem_object *obj)
 EXPORT_SYMBOL(drm_gem_free_mmap_offset);
 
 /**
  * drm_gem_create_mmap_offset - create a fake mmap offset for an object
  * @obj: obj in question
+ * @size: the virtual size
  *
  * GEM memory mapping works by handing back to userspace a fake mmap offset
  * it can use in a subsequent mmap(2) call.  The DRM core code then looks
  * up the object based on the offset and sets up the various memory mapping
  * structures.
  *
- * This routine allocates and attaches a fake offset for @obj.
+ * This routine allocates and attaches a fake offset for @obj, in cases where
+ * the virtual size differs from the physical size (ie. obj->size).  Otherwise
+ * just use drm_gem_create_mmap_offset().
  */
 int
-drm_gem_create_mmap_offset(struct drm_gem_object *obj)
+drm_gem_create_mmap_offset_size(struct drm_gem_object *obj, size_t size)
 {
 	struct drm_device *dev = obj->dev;
 	struct drm_gem_mm *mm = dev->mm_private;
 
 	return drm_vma_offset_add(&mm->vma_manager, &obj->vma_node,
-				  obj->size / PAGE_SIZE);
+				  size / PAGE_SIZE);
+}
+EXPORT_SYMBOL(drm_gem_create_mmap_offset_size);
+
+/**
+ * drm_gem_create_mmap_offset - create a fake mmap offset for an object
+ * @obj: obj in question
+ *
+ * GEM memory mapping works by handing back to userspace a fake mmap offset
+ * it can use in a subsequent mmap(2) call.  The DRM core code then looks
+ * up the object based on the offset and sets up the various memory mapping
+ * structures.
+ *
+ * This routine allocates and attaches a fake offset for @obj.
+ */
+int drm_gem_create_mmap_offset(struct drm_gem_object *obj)
+{
+	return drm_gem_create_mmap_offset_size(obj, obj->size);
 }
 EXPORT_SYMBOL(drm_gem_create_mmap_offset);
 
@@ -303,24 +303,44 @@ drm_gem_free_mmap_offset(struct drm_gem_object *obj)
 
 /**
- * drm_gem_create_mmap_offset - create a fake mmap offset for an object
+ * drm_gem_create_mmap_offset_size - create a fake mmap offset for an object
  * @obj: obj in question
-- 
1.8.3.1

  parent reply	other threads:[~2013-08-07 17:42 UTC|newest]

Thread overview: 20+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2013-08-07 17:41 [PATCH 0/9] deps for msm drm (flip-work helper, const ioctl table, and gem helpers) Rob Clark
2013-08-07 17:41 ` [PATCH 1/9] drm: add flip-work helper Rob Clark
2013-08-07 17:49   ` Daniel Vetter
2013-08-07 18:20     ` Rob Clark
2013-08-07 18:41       ` Rob Clark
2013-08-07 17:41 ` [PATCH 2/9] drm/tilcdc: use " Rob Clark
2013-08-07 17:41 ` [PATCH 3/9] drm/omap: " Rob Clark
2013-08-07 17:41 ` [PATCH 4/9] drm: const'ify ioctls table (v2) Rob Clark
2013-08-07 17:48   ` Rob Clark
2013-08-07 17:41 ` Rob Clark [this message]
2013-08-08 15:29   ` [PATCH 5/9] drm/gem: add drm_gem_create_mmap_offset_size() David Herrmann
2013-08-07 17:41 ` [PATCH 6/9] drm/gem: add shmem get/put page helpers Rob Clark
2013-08-07 17:41 ` [PATCH 7/9] drm/gma500: use gem " Rob Clark
2013-10-08 19:57   ` Guillaume CLÉMENT
2013-10-08 20:19     ` Rob Clark
2013-10-08 20:22       ` Patrik Jakobsson
2013-10-08 20:31     ` Guillaume CLÉMENT
2013-08-07 17:41 ` [PATCH 8/9] drm/udl: " Rob Clark
2013-08-07 17:41 ` [PATCH 9/9] drm/omap: kill omap_gem_helpers.c Rob Clark
2013-08-07 20:13   ` Daniel Vetter

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1375897287-8787-6-git-send-email-robdclark@gmail.com \
    --to=robdclark@gmail.com \
    --cc=dri-devel@lists.freedesktop.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.